@@ -1,17 +1,16 @@
 package Dist::Zilla::Plugin::ModuleIncluder;
-{
-  $Dist::Zilla::Plugin::ModuleIncluder::VERSION = '0.004';
-}
+$Dist::Zilla::Plugin::ModuleIncluder::VERSION = '0.005';
+# vim: ts=4 sts=0 sw=0 noet
 use version;
 use Moose;
-
-use version;
+use MooseX::Types::Moose qw/ArrayRef Bool/;
 use MooseX::Types::Perl 'VersionObject';
+use MooseX::Types::Stringlike 'Stringlike';
 
 with qw/Dist::Zilla::Role::ModuleIncluder Dist::Zilla::Role::FileGatherer/;
 
 has module => (
-	isa => 'ArrayRef[Str]',
+	isa => ArrayRef[Stringlike],
 	traits => ['Array'],
 	handles => {
 		modules => 'elements',
@@ -20,7 +19,7 @@ has module => (
 );
 
 has blacklist => (
-	isa => 'ArrayRef[Str]',
+	isa => ArrayRef[Stringlike],
 	traits => ['Array'],
 	handles => {
 		blacklisted_modules => 'elements',
@@ -37,7 +36,7 @@ has background_perl => (
 
 has only_deps => (
 	is => 'ro',
-	isa => 'Bool',
+	isa => Bool,
 	default => 0,
 );
 
@@ -71,7 +70,7 @@ Dist::Zilla::Plugin::ModuleIncluder - explicitly include modules into a distribu
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -82,6 +81,7 @@ In dist.ini:
  module = Bar
  background_perl = 5.008001 #default value
  only_deps = 0 #default
+ include_dependencies = 1 #default
 
 =head1 DESCRIPTION
 
@@ -101,6 +101,10 @@ Set the background perl version. If the (appropriate version of the) module was
 
 Do not include the specified modules, only their dependencies. Note that it still includes the module if something else depends on it.
 
+=item * blacklist
+
+The name of a module to never include.  This option can be given more than once.
+
 =back
 
 =for Pod::Coverage gather_files
